@@ -22,6 +22,7 @@ class Admin:
     def enable_admin(self):
         self.enable_cheats(self.__password)
         self.gcm()
+        self.enemy_ignores_me()
         self.execute()
         return self
 
@@ -45,10 +46,6 @@ class Admin:
         self.command_list.append(PlayerManagement.LEAVE_ME_ALONE)
         return self
 
-    def enemy_invisible(self):
-        self.command_list.append(PlayerManagement.ENEMY_INVISIBLE)
-        return self
-
     def enemy_ignores_me(self, condition=True):
         """ Enemy creatures ignore me """
         condition = "true" if condition else "false"
@@ -465,6 +462,22 @@ class Admin:
             PlayerManagement.ADD_EXPERIENCE.format(amount, from_tribe_share, prevent_sharing_with_tribe))
         return self
 
+    def set_time_of_day(self, hour: int = 8, minute: int = 0, seconds: int = 0):
+        self.command_list.append(Map.SET_TIME_OF_DAY.format(hour, minute, seconds))
+        return self
+
+    def morning(self):
+        return self.set_time_of_day(hour=4, minute=30)
+
+    def daylight(self):
+        return self.set_time_of_day(hour=10)
+
+    def dusk(self):
+        return self.set_time_of_day(hour=21)
+
+    def night(self):
+        return self.set_time_of_day(hour=24)
+
     def __enter__(self):
         return self
 
